@@ -7,6 +7,8 @@ from tcell_agent.instrumentation.decorators import catches_generic_exception
 from tcell_agent.instrumentation.manager import InstrumentationManager
 from tcell_agent.instrumentation.utils import get_tcell_context
 from tcell_agent.utils.compat import a_string
+from tcell_agent.config.configuration import get_config
+from tcell_agent.tcell_logger import get_module_logger
 
 
 @catches_generic_exception(__name__,
@@ -209,4 +211,9 @@ def instrument_os_system():
 
 @catches_generic_exception(__name__, "Could not instrument for cmdi")
 def instrument_commands():
+    if 'os-commands' in get_config().disabled_instrumentation:
+        logger = get_module_logger(__name__)
+        if logger is not None:
+            logger.info("Skipping instrumentation for OS Commands feature")
+        return
     instrument_os_system()
