@@ -9,7 +9,6 @@ from tcell_agent.agent import TCellAgent
 from tcell_agent.config.configuration import get_config
 from tcell_agent.instrumentation.decorators import catches_generic_exception
 from tcell_agent.instrumentation.djangoinst.settings import send_django_setting_events
-from tcell_agent.events.server_agent_framework_event import ServerAgentFrameworkEvent
 
 
 AGENT_STARTED_LOCK = threading.Lock()
@@ -21,7 +20,8 @@ def start_agent():
         if has_agent_started():
             return False
 
-        if TCellAgent.startup():
+        framework_details = {"app_framework": "Django", "app_framework_version": get_version()}
+        if TCellAgent.startup(framework_details):
             set_agent_has_started()
             return True
 
@@ -37,6 +37,4 @@ def ensure_agent_started():
         update_default_charset(settings.DEFAULT_CHARSET)
 
     if get_config().enabled and start_agent():
-        sade = ServerAgentFrameworkEvent("Django", get_version())
-        TCellAgent.send(sade)
         send_django_setting_events()
