@@ -15,4 +15,6 @@ def set_native_agent(native_agent):
 
 
 def get_module_logger(module_name):
-    return _NATIVE_AGENT.get_module_logger(module_name)
+    if _NATIVE_AGENT:
+        return _NATIVE_AGENT.get_module_logger(module_name)
+    return None
