@@ -44,6 +44,8 @@ class EndTimerTest(unittest.TestCase):
             "user_id", "user-id"
         ).update_attribute(
             "path", "/path"
+        ).update_attribute(
+            "reverse_proxy_header_value", "2.2.2.2"
         ).build()
 
         request = Mock(_tcell_context=context)
@@ -63,6 +65,7 @@ class EndTimerTest(unittest.TestCase):
                                            1001,
                                            "1.1.1.1",
                                            "user-agent",
+                                           "2.2.2.2",
                                            "session-id",
                                            "user-id")])
                     self.assertEqual(logger_mock.debug.call_args_list,
