@@ -1,15 +1,13 @@
 import unittest
 
 from tcell_agent.policies.headers_policy import HeadersPolicy
-from tcell_agent.rust.native_agent import create_native_agent
-from tcell_agent.tests.support.builders import ConfigurationBuilder, ContextBuilder
+from tcell_agent.tests.support.builders import ContextBuilder, NativeAgentBuilder
 from tcell_agent.tests.support.free_native_agent import free_native_agent
 
 
 class SecureHeaderPolicyTest(unittest.TestCase):
     def setUp(self):
-        configuration = ConfigurationBuilder().build()
-        self.native_agent = create_native_agent(configuration)
+        self.native_agent = NativeAgentBuilder()
         self.tcell_context = ContextBuilder().update_attribute(
             "session-id", "session-id"
         ).update_attribute(
